@@ -14,7 +14,7 @@ sampleN.NTIDFDA <- function(alpha=0.05, targetpower=0.8, theta0, theta1, theta2,
   if (missing(theta0)) theta0 <- 0.975      # tighter content requirement
   if (missing(theta2)) theta2=1/theta1
   if ( (theta0<=theta1) | (theta0>=theta2) ) {
-    stop("Null ratio ",theta0," not between margins ",theta1," / ",theta2,"!", 
+    stop("True ratio ",theta0," not between margins ",theta1," / ",theta2,"!", 
          call.=FALSE)
   }
   if (missing(CV)) stop("CV(s) must be given!", call.=FALSE)
@@ -78,10 +78,10 @@ sampleN.NTIDFDA <- function(alpha=0.05, targetpower=0.8, theta0, theta1, theta2,
     cat(nsims,"studies for each step simulated.\n\n")
     cat("alpha  = ",alpha,", target power = ", targetpower,"\n", sep="")
     cat("CVw(T) = ",CVwT,", CVw(R) = ",CVwR,"\n", sep="")
-    cat("Null (true) ratio =",theta0,"\n")
-    cat("ABE limits        =", theta1, "...", theta2,"\n")
+    cat("True ratio     =",theta0,"\n")
+    cat("ABE limits     =", theta1, "...", theta2,"\n")
     if (details) {
-      cat("Implied scABEL    =", formatC(exp(ltheta1), format="f", digits=4), 
+      cat("Implied scABEL =", formatC(exp(ltheta1), format="f", digits=4), 
           "...", formatC(exp(ltheta2), format="f", digits=4),"\n")
     }
     cat("Regulatory settings:",regulator,"\n")
